@@ -71,7 +71,7 @@ use Params::Util qw{_INSTANCE _STRING};
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.108';
+	$VERSION = '1.109';
 }
 
 
@@ -182,6 +182,23 @@ sub _weight {
 
 =pod
 
+=head2 weight_merged @names
+
+The C<weight_merged> method takes the name of a set of items and
+calculates an aggregated weight for the whole set.
+
+Returns the weight as a scalar, or C<undef> on error.
+
+=cut
+
+sub weight_merged {
+	my $self  = shift;
+	my $items = $self->{algdep}->schedule(@_) or return undef;
+	scalar(@$items);
+}
+
+=pod
+
 =head2 weight_hash @names
 
 The C<weight_hash> method takes a list of item names, and calculates
